@@ -1,21 +1,7 @@
 /*
-    Copyright 2014 Alejandro Fiestas Olivares <afiestas@kde.org>
+    SPDX-FileCopyrightText: 2014 Alejandro Fiestas Olivares <afiestas@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library. If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #ifndef SOLID_JOB_H
@@ -54,14 +40,14 @@ class SOLID_EXPORT Job : public QObject
     Q_PROPERTY(QString errorText READ errorText NOTIFY result)
 
 public:
-    explicit Job(QObject* parent = nullptr);
+    explicit Job(QObject *parent = nullptr);
     virtual ~Job();
 
     enum Error {
         /** Indicates there is no error */
         NoError = 0,
         /** Subclasses should define error codes starting at this value */
-        UserDefinedError = 100
+        UserDefinedError = 100,
     };
     Q_ENUM(Error)
 
@@ -175,7 +161,8 @@ protected:
     void emitResult();
 
     JobPrivate *const d_ptr;
-    Job(JobPrivate &dd, QObject *parent);
+    SOLID_NO_EXPORT Job(JobPrivate &dd, QObject *parent);
+
 private:
     Q_DECLARE_PRIVATE(Job)
 
@@ -183,6 +170,5 @@ Q_SIGNALS:
     void result(Solid::Job *job);
 };
 }
-Q_DECLARE_METATYPE(Solid::Job::Error)
 
-#endif //SOLID_JOB_H
+#endif // SOLID_JOB_H
